@@ -1,8 +1,8 @@
-from pydantic import BaseModel
+from .model import Type
 
 from datetime import datetime
 
-class Work_Task(BaseModel):
+class Work_Task(Type):
     id: int
     id_str: str
     person: int
@@ -13,7 +13,7 @@ class Work_Task(BaseModel):
     targetDate: datetime
 
 
-class Work(BaseModel):
+class Work(Type):
     """[GET/POST/DELETE/PUT]\n~~~\n/v2.0/works\n~~~\n/v2.0/lessons/{lesson}/works\n~~~\n/v2.0/works/{work}\n~~~\n/v2.0/works/many\n~~~\nПолучение списка всех типов работ школы (Данный класс - 1 тип работы)\n~~~\nПрава доступа: EducationalInfo\n~~~"""
     
     id: int
@@ -41,7 +41,7 @@ class Work(BaseModel):
     oneDriveLinks: list[int] | None = []
 
 
-class EditStatusHomeWork(BaseModel):
+class EditStatusHomeWork(Type):
     """[POST]\n~~~\n/v2.0/works/{work}/persons/{person}/status\n~~~\nИзменить статус выполнения домашней работы учащимся.\n~~~\nПрава доступа: EducationalInfo\n~~~"""
     
     id: int
